==> nextcloud-app-tasks-0.16.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/cy_GB.js <==
OC.L10N.register(
    "tasks",
    {
    "Today" : "Heddiw",
    "Week" : "Wythnos",
    "All" : "Popeth",
    "Hidden" : "Cudd",
    "Visible" : "Gweladwy",
    "Automatic" : "Awtomatig",
    "Share with users or groups" : "Rhannwch gyda defnyddwyr neu grwpiau",
    "No users or groups" : "Dim defnyddwyr na grwpiau",
    "Can edit" : "Can edit",
    "Unshare with {displayName}" : "Dadrannu gyda {displayName}",
    "Unable to delete the share." : "Methu dileu'r gyfran.",
    "Unable to change permissions." : "Methu newid caniatâd.",
    "Edit" : "Golygu",
    "Copy private link" : "Copïo dolen breifat",
    "Copied" : "Copïwyd",
    "Export" : "Allforio",
    "Delete" : "Dileu",
    "Unshare" : "Dad-rannu",
    "Calendar link copied to clipboard." : "Dolen calendr wedi'i chopïo i'r clipfwrdd.",
    "Calendar link could not be copied to clipboard." : "Nid oedd modd copïo dolen calendr i'r clipfwrdd.",
    "An error occurred, unable to delete the calendar." : "Bu gwall, ni fu modd dileu'r calendr.",
    "Trash bin" : "Bin sbwriel",
    "Name" : "Enw",
    "Deleted" : "Wedi dileu",
    "Restore" : "Adfer",
    "Delete permanently" : "Dileu'n barhaol",
    "Empty trash bin" : "Bin sbwriel gwag",
    "Untitled task" : "Tasg di-deitl",
    "Untitled event" : "Digwyddiad di-deitl",
    "Unknown calendar" : "Calendr anhysbys",
    "Could not load deleted calendars and objects" : "Methu llwytho calendrau a gwrthrychau wedi'u dileu",
    "Could not restore calendar or event" : "Methu ag adfer calendr neu ddigwyddiad",
    "Do you really want to empty the trash bin?" : "Ydych chi wir eisiau gwagio'r bin sbwriel?",
    "Cancel" : "Diddymu",
    "Close" : "Cau",
    "No errors" : "Dim gwallau",
    "Open your browser console for more details" : "Agorwch eich consol porwr am fwy o fanylion",
    "Last modified" : "Newidiwyd diwethaf",
    "Alphabetically" : "Trefn yr Wyddor",
    "[Yesterday]" : "[Ddoe]",
    "[Today]" : "Heddiw",
    "[Tomorrow]" : "[Yfory]",
    "All day" : "Drwy'r dydd",
    "Details" : "Manylion",
    "Notes" : "Nodiadau",
    "Reminders" : "Nodau atgoffa",
    "Repeat" : "Ailadrodd",
    "When shared show full event" : "Pan wedi ei rannu, yn dangos y digwyddiad llawn",
    "When shared show only busy" : "Pan wedi ei rannu, yn dangos dim ond prysur",
    "When shared hide this event" : "Pan wedi ei rannu, yn cuddio'r digwyddiad hwn",
    "Canceled" : "Wedi diddymu",
    "An error occurred" : "Digwyddodd gwall"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");

==> nextcloud-app-tasks-0.17.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/cy_GB.js <==
OC.L10N.register(
    "tasks",
    {
    "Today" : "Heddiw",
    "Week" : "Wythnos",
    "All" : "Popeth",
    "Hidden" : "Cudd",
    "Visible" : "Gweladwy",
    "Automatic" : "Awtomatig",
    "Share with users or groups" : "Rhannwch gyda defnyddwyr neu grwpiau",
    "No users or groups" : "Dim defnyddwyr na grwpiau",
    "Unable to delete the share." : "Methu dileu'r gyfran.",
    "Unable to change permissions." : "Methu newid caniatâd.",
    "Can edit" : "Can edit",
    "Unshare with {displayName}" : "Dadrannu gyda {displayName}",
    "Calendar link copied to clipboard." : "Dolen calendr wedi'i chopïo i'r clipfwrdd.",
    "Calendar link could not be copied to clipboard." : "Nid oedd modd copïo dolen calendr i'r clipfwrdd.",
    "An error occurred, unable to delete the calendar." : "Bu gwall, ni fu modd dileu'r calendr.",
    "Edit" : "Golygu",
    "Copy private link" : "Copïo dolen breifat",
    "Copied" : "Copïwyd",
    "Export" : "Allforio",
    "Delete" : "Dileu",
    "Unshare" : "Dad-rannu",
    "Untitled task" : "Tasg di-deitl",
    "Untitled event" : "Digwyddiad di-deitl",
    "Unknown calendar" : "Calendr anhysbys",
    "Could not load deleted calendars and objects" : "Methu llwytho calendrau a gwrthrychau wedi'u dileu",
    "Could not restore calendar or event" : "Methu ag adfer calendr neu ddigwyddiad",
    "Do you really want to empty the trash bin?" : "Ydych chi wir eisiau gwagio'r bin sbwriel?",
    "Empty trash bin" : "Bin sbwriel gwag",
    "Trash bin" : "Bin sbwriel",
    "Name" : "Enw",
    "Deleted" : "Wedi dileu",
    "Restore" : "Adfer",
    "Delete permanently" : "Dileu'n barhaol",
    "Cancel" : "Diddymu",
    "Notification" : "Hysbysiad",
    "Email" : "E-bost",
    "Audio notification" : "Hysbysiad sain",
    "Other notification" : "Hysbysiad arall",
    "Edit time" : "Golygu amser",
    "Remove reminder" : "Dileu nodyn atgoffa",
    "Add reminder" : "Ychwanegu nodyn atgoffa",
    "Go back" : "Nôl",
    "before at" : "cyn am",
    "_second_::_seconds_" : ["eiliad","eiliad","eiliad","eiliad"],
    "_minute_::_minutes_" : ["munud","munud","munud","munud"],
    "_hour_::_hours_" : ["awr","awr","awr","awr"],
    "_day_::_days_" : ["diwrnod","diwrnod","diwrnod","diwrnod"],
    "_week_::_weeks_" : ["wythnos","wythnos","wythnos","wythnos"],
    "Close" : "Cau",
    "No errors" : "Dim gwallau",
    "Open your browser console for more details" : "Agorwch eich consol porwr am fwy o fanylion",
    "Last modified" : "Newidiwyd diwethaf",
    "Alphabetically" : "Trefn yr Wyddor",
    "Tags" : "Tagiau",
    "[Yesterday]" : "[Ddoe]",
    "[Today]" : "Heddiw",
    "[Tomorrow]" : "[Yfory]",
    "When shared show full event" : "Pan wedi ei rannu, yn dangos y digwyddiad llawn",
    "When shared show only busy" : "Pan wedi ei rannu, yn dangos dim ond prysur",
    "When shared hide this event" : "Pan wedi ei rannu, yn cuddio'r digwyddiad hwn",
    "Canceled" : "Wedi diddymu",
    "All day" : "Drwy'r dydd",
    "Details" : "Manylion",
    "Notes" : "Nodiadau",
    "An error occurred" : "Digwyddodd gwall"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
